@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: A data processor class
 
-our $VERSION = '1.111560'; # VERSION
+our $VERSION = '1.111590'; # VERSION
 
 use Moose;
 with 'DataFlow::Role::Processor';
@@ -57,13 +57,6 @@ has 'deref' => (
     'default' => 0,
 );
 
-has 'process_into' => (
-    'is'      => 'ro',
-    'isa'     => 'Bool',
-    'lazy'    => 1,
-    'default' => 1,
-);
-
 has 'dump_input' => (
     'is'            => 'ro',
     'isa'           => 'Bool',
@@ -85,10 +78,7 @@ has 'policy' => (
     'isa'     => 'ProcPolicy',
     'coerce'  => 1,
     'lazy'    => 1,
-    'default' => sub {
-        my $self = shift;
-        return $self->process_into ? 'ProcessInto' : 'Scalar';
-    },
+    'default' => 'ProcessInto',
 );
 
 has 'p' => (
@@ -149,7 +139,7 @@ DataFlow::Proc - A data processor class
 
 =head1 VERSION
 
-version 1.111560
+version 1.111590
 
 =head1 SYNOPSIS
 
@@ -207,14 +197,6 @@ or if DataFlow::Proc will filter those out. (DEFAULT = false)
 upon output or if DataFlow::Proc will preserve the original reference.
 (DEFAULT = false)
 
-=head2 process_into
-
-[Bool] It signals whether this processor will attempt to process data within
-references or not. If process_into is true, then C<process_item> will be
-applied into the values referenced by any scalar, array or hash reference and
-onto the result of running any code reference.
-(DEFAULT = true)
-
 =head2 dump_input
 
 [Bool] Dumps the input parameter to STDERR before processing. See
