@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: A role that defines how to use proc-handlers
 
-our $VERSION = '1.111560'; # VERSION
+our $VERSION = '1.111590'; # VERSION
 
 use Moose::Role;
 
@@ -20,12 +20,9 @@ has 'handlers' => (
 );
 
 has 'default_handler' => (
-    'is'      => 'ro',
-    'isa'     => 'CodeRef',
-    'lazy'    => 1,
-    'default' => sub {
-        shift->confess(q{Must provide a default handler!});
-    },
+    'is'       => 'ro',
+    'isa'      => 'CodeRef',
+    'required' => 1,
 );
 
 sub apply {
@@ -51,16 +48,17 @@ sub _make_apply_ref {
     return sub { $self->apply( $p, $_ ) };
 }
 
-sub _nop_handle {    ## no critic
-    return $_[1];
-}
-
 sub _run_p {
     my ( $p, $item ) = @_;
     local $_ = $item;
     return $p->();
 }
 
+sub _nop_handle {
+    my @param = @_;      # ( p, item )
+    return $param[1];    # nop handle: ignores p, returns item itself
+}
+
 sub _handle_svalue {
     my ( $p, $item ) = @_;
     return _run_p( $p, $item );
@@ -106,7 +104,7 @@ DataFlow::Role::ProcPolicy - A role that defines how to use proc-handlers
 
 =head1 VERSION
 
-version 1.111560
+version 1.111590
 
 =head2 apply P ITEM
 
